# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dialoghelper',
                'doc_host': 'https://AnswerDotAI.github.io',
                'git_url': 'https://github.com/AnswerDotAI/dialoghelper',
                'lib_path': 'dialoghelper'},
  'syms': { 'dialoghelper.core': { 'dialoghelper.core._add_msg_unsafe': ('core.html#_add_msg_unsafe', 'dialoghelper/core.py'),
                                   'dialoghelper.core._msg': ('core.html#_msg', 'dialoghelper/core.py'),
                                   'dialoghelper.core._umsg': ('core.html#_umsg', 'dialoghelper/core.py'),
                                   'dialoghelper.core.add_html': ('core.html#add_html', 'dialoghelper/core.py'),
                                   'dialoghelper.core.add_msg': ('core.html#add_msg', 'dialoghelper/core.py'),
                                   'dialoghelper.core.del_msg': ('core.html#del_msg', 'dialoghelper/core.py'),
                                   'dialoghelper.core.export_dialog': ('core.html#export_dialog', 'dialoghelper/core.py'),
                                   'dialoghelper.core.find_dialog_id': ('core.html#find_dialog_id', 'dialoghelper/core.py'),
                                   'dialoghelper.core.find_msg_id': ('core.html#find_msg_id', 'dialoghelper/core.py'),
                                   'dialoghelper.core.find_msgs': ('core.html#find_msgs', 'dialoghelper/core.py'),
                                   'dialoghelper.core.find_var': ('core.html#find_var', 'dialoghelper/core.py'),
                                   'dialoghelper.core.get_db': ('core.html#get_db', 'dialoghelper/core.py'),
                                   'dialoghelper.core.gist_file': ('core.html#gist_file', 'dialoghelper/core.py'),
                                   'dialoghelper.core.import_dialog': ('core.html#import_dialog', 'dialoghelper/core.py'),
                                   'dialoghelper.core.import_gist': ('core.html#import_gist', 'dialoghelper/core.py'),
                                   'dialoghelper.core.import_string': ('core.html#import_string', 'dialoghelper/core.py'),
                                   'dialoghelper.core.is_usable_tool': ('core.html#is_usable_tool', 'dialoghelper/core.py'),
                                   'dialoghelper.core.load_gist': ('core.html#load_gist', 'dialoghelper/core.py'),
                                   'dialoghelper.core.mk_toollist': ('core.html#mk_toollist', 'dialoghelper/core.py'),
                                   'dialoghelper.core.msg_idx': ('core.html#msg_idx', 'dialoghelper/core.py'),
                                   'dialoghelper.core.read_msg': ('core.html#read_msg', 'dialoghelper/core.py'),
                                   'dialoghelper.core.read_msg_ids': ('core.html#read_msg_ids', 'dialoghelper/core.py'),
                                   'dialoghelper.core.tool_info': ('core.html#tool_info', 'dialoghelper/core.py'),
                                   'dialoghelper.core.update_msg': ('core.html#update_msg', 'dialoghelper/core.py')},
            'dialoghelper.db_dc': {}}}
